<!--
    =====================================
    generator=datazen
    version=2.1.0
    hash=8e2fca2b8f4beaa45ee1de8fa0b0665f
    =====================================
-->

# setuptools-wrapper ([0.1.0](https://pypi.org/project/setuptools-wrapper/))

[![python](https://img.shields.io/pypi/pyversions/setuptools-wrapper.svg)](https://pypi.org/project/setuptools-wrapper/)
![Build Status](https://github.com/vkottler/setuptools-wrapper/workflows/Python%20package/badge.svg)
[![codecov](https://codecov.io/gh/vkottler/setuptools-wrapper/branch/master/graphs/badge.svg?branch=master)](https://codecov.io/github/vkottler/setuptools-wrapper)

*A simple interface to setuptools's setup function.*

That's it. I personally think there are way too many configuration options when
"packaging" software and I want to homogenize my own packages. Thus:
`setuptools-wrapper`.

# Internal Dependency Graph

A coarse view of the internal structure and scale of
`setuptools-wrapper`'s source.
Generated using [pydeps](https://github.com/thebjorn/pydeps) (via
`mk python-deps`).

![setuptools-wrapper's Dependency Graph](im/pydeps.svg)
